@@ -8,8 +8,11 @@ from pymongo import MongoClient,ReadPreference
 from scrapy.utils.conf import get_config
 import os
 import logging
+import time
 from datetime import datetime
 
+from twisted.internet.threads import deferToThread
+
 class MongodbPipeline(object):
     def __init__(self,MONGO_HOST,MONGO_PORT,MONGO_PSW,MONGO_USER,MONGO_DB,AUTH_SOURCE,SECTION_SELECT):
         # 链接数据库
@@ -43,7 +46,7 @@ class MongodbPipeline(object):
                    AUTH_SOURCE=get_config().get(section=section_select,option='AUTH_SOURCE',fallback='') or crawler.settings.get('AUTH_SOURCE'),
                    SECTION_SELECT = section_select)
 
-    def process_item(self, item, spider):
+    def _process_item(self, item, spider):
         date_time = datetime.now().strftime("_%Y_%m") if self.section_select=='mongo_cfg_prod' else ""
         postItem = dict(item)
         if postItem.get("brand_id", None):  # brand_id :: int
@@ -94,6 +97,10 @@ class MongodbPipeline(object):
             postItem["mpq"] = int(postItem["mpq"])
         if postItem.get("rough_weight", None):  # rough_weight :: float #注意:单位g
             postItem["rough_weight"] = float(postItem["rough_weight"])
+        if postItem.get('create_time', None):  # create_time标准时间格式2022-01-01 00:00:00
+            postItem['create_time'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
+        if postItem.get('spider_time', None):  # spider_time标准时间格式2022-01-01 00:00:00
+            postItem['spider_time'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
         msg = postItem.get("title", "") or postItem.get("category_name","") or postItem.get("url","") or postItem.get("sources","") # or postItem.get("")
         try:
              # 把item转化成字典形式
@@ -104,5 +111,8 @@ class MongodbPipeline(object):
             logging.info(f'去重 {msg} Skip .') 
         return item
 
+    def process_item(self, item, spider):
+        return deferToThread(self._process_item, item, spider)
+
     def close_spider(self,spider):
         self.client.close()
