@@ -274,10 +274,11 @@ class OssFilesPipeline(MediaPipeline):
                 except PdfReadError as e:
                     if "EOF marker not found" in str(e):
                         break
-                    else:
+                    elif "not found" in str(e):
                         print(response.request.headers)
+                        print(str(e))
                         headers = Headers(response.request.headers).to_unicode_dict()
-                        contents = requests.get(response.request.url,headers = headers).content
+                        contents = requests.get(response.request.url,headers = headers, timeout=(10,120)).content
                         response = response.replace(body=contents)
                         response = check_eof_error(response)
                         logging.info(f"Retry {i+1} times , Url is {response.request.url}")
@@ -288,7 +289,7 @@ class OssFilesPipeline(MediaPipeline):
             except PdfReadError as e:
                 if "EOF marker not found" in str(e):
                     pass
-                else:
+                elif "not found" in str(e):
                     return
                     
         if self.invalid_fild_path:
